#!/bin/sh
# script for execution of deployed applications
#
# Sets up the MCR environment for the current $ARCH and executes 
# the specified command.
#
exe_name=$0
exe_dir=`dirname "$0"`
if [ $# -lt "8" ]; then
echo "----------------------------------------------------------------------------------------------"
echo "Usage:
./run_fcm_var_q2_Release_v1.sh filename N beta thresh outputdir modal e1 e2 e3 e4 e5 
All arguments are needed except e3, e4,e5.

This is a code for Fuzzy C means with variable compactness, ref.
S. Roy, H. Agarwal, A. Carass, Y. Bai, D. L. Pham, J. L. Prince,
'Fuzzy c-means with variable compactness', ISBI, 2008.

FILENAME = A string containing MIPAV XML(.xml) or NIFTI(.nii) volumes. 
N = Number of classes
BETA = Smoothness factor, should be [0,0.2]
THRESH = Background threshold, usually zero. Any value below the THRESHOLD 
is ignored from computation.
OUTPUTDIR = A writable directory where the output membership (FLOAT and
segmentation volume (UNSIGNED BYTE) will be written.
MODAL = Either SPGR (enter spgr) or MPRAGE (enter mprage)
Compactness parameters are mentioned in e1 to e5. Minimum 2 and maximum 
5 classes are supported.
Initial centroids are estimated automatically based on the MODALITY.
A typical value of compactness parameters for SPGR is [1.1 1 1], for 
MPRAGE [0.8 1 1]. As a thumb rule, if the cluster variance is small, use
compactness parameter smaller than 1 (e.g. CSF in MPRAGE).

This executable is compatible with 2012a version, anything less may not work.
Default MCR root is /usr/matlab_2012a. If that is not correct, change the 
MCRROOT to the appropriate directory in this script (Line 63)."
echo "----------------------------------------------------------------------------------------------"
exit 1
else
 FILE=$1
 N=$2
 BETA=$3
 TH=$4
 OUT=$5 
 MODAL=$6
for ((i=7; i<=7+$N; ++i )) ; 
do
    if [ $i -eq "7" ]; then
      	E1=$7
    elif [ $i -eq "8" ]; then
	E2=$8
    elif [ $i -eq "9" ]; then
	E3=$9
    elif [ $i -eq "10" ]; then
	E4=${10}
    else
       E5=${11} 
    fi
done


  echo Setting up environment variables
#  MCRROOT=/usr/matlab_2012a
MCRROOT=/home/roy/Matlab_Compiler_Runtime/v717
  LD_LIBRARY_PATH=.:${MCRROOT}/runtime/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/bin/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/sys/os/glnxa64;
	MCRJRE=${MCRROOT}/sys/java/jre/glnxa64/jre/lib/amd64 ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/native_threads ; 
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/server ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/client ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE} ;  
  XAPPLRESDIR=${MCRROOT}/X11/app-defaults ;
  export LD_LIBRARY_PATH;
  export XAPPLRESDIR;
#  echo LD_LIBRARY_PATH is ${LD_LIBRARY_PATH};
  shift 1
  
echo "${exe_dir}"/fcm_var_q2_Release $FILE $N $BETA $TH $OUT $MODAL $E1 $E2 $E3 $E4 $E5
  "${exe_dir}"/fcm_var_q2_Release $FILE $N $BETA $TH $OUT $MODAL $E1 $E2 $E3 $E4 $E5
fi
exit

